/*
 * $Id$
 */

package org.codehaus.mojo.nbm.model;

  //---------------------------------/
 //- Imported classes and packages -/
//---------------------------------/

import java.util.Date;

/**
 * Describes the layout, dependencies and packaging of a Netbeans
 * module.
 * 
 * @version $Revision$ $Date$
 */
public class NetbeansModule implements java.io.Serializable {


      //--------------------------/
     //- Class/Member Variables -/
    //--------------------------/

    /**
     * Field moduleType
     */
    private String moduleType = "normal";

    /**
     * Field codeNameBase
     */
    private String codeNameBase;

    /**
     * Field cluster
     */
    private String cluster = "maven1";

    /**
     * Field requiresRestart
     */
    private boolean requiresRestart = false;

    /**
     * Field manifest
     */
    private String manifest = "src/main/nbm/manifest.mf";

    /**
     * Field homepageUrl
     */
    private String homepageUrl;

    /**
     * Field distributionUrl
     */
    private String distributionUrl;

    /**
     * Field author
     */
    private String author;

    /**
     * Field licenseName
     */
    private String licenseName;

    /**
     * Field licenseFile
     */
    private String licenseFile;

    /**
     * Field libraries
     */
    private java.util.List libraries;

    /**
     * Field dependencies
     */
    private java.util.List dependencies;

    /**
     * Field nbmResources
     */
    private java.util.List nbmResources;


      //-----------/
     //- Methods -/
    //-----------/

    /**
     * Method addDependency
     * 
     * @param dependency
     */
    public void addDependency(Dependency dependency)
    {
        getDependencies().add( dependency );
    } //-- void addDependency(Dependency) 

    /**
     * Method addLibrary
     * 
     * @param string
     */
    public void addLibrary(String string)
    {
        getLibraries().add( string );
    } //-- void addLibrary(String) 

    /**
     * Method addNbmResource
     * 
     * @param nbmResource
     */
    public void addNbmResource(NbmResource nbmResource)
    {
        getNbmResources().add( nbmResource );
    } //-- void addNbmResource(NbmResource) 

    /**
     * Get Author of the module. Is used when generating the NBM
     * file.
     */
    public String getAuthor()
    {
        return this.author;
    } //-- String getAuthor() 

    /**
     * Get Each modules should belong to a cluster. A cluster is a
     * group of related modules. For individual modules it's not
     * that important. Refer to netbeans.org documentation for more
     * details.
     */
    public String getCluster()
    {
        return this.cluster;
    } //-- String getCluster() 

    /**
     * Get Codenamebase of the module. Primary identification of
     * the module. Usually the package name. Eg.
     * "org.codehaus.mevenide.project". 
     *                     If not defined here, the default value
     * is constructed from groupId and artifactId.
     */
    public String getCodeNameBase()
    {
        return this.codeNameBase;
    } //-- String getCodeNameBase() 

    /**
     * Method getDependencies
     */
    public java.util.List getDependencies()
    {
        if ( this.dependencies == null )
        {
            this.dependencies = new java.util.ArrayList();
        }
        
        return this.dependencies;
    } //-- java.util.List getDependencies() 

    /**
     * Get Http URL of the location where the module can be
     * downloaded from the internet. This value put into the NBM
     * and used when generating the Autoupdate Site. Should point
     * directly to the NBM download.
     */
    public String getDistributionUrl()
    {
        return this.distributionUrl;
    } //-- String getDistributionUrl() 

    /**
     * Get Homepage URL of the module. Is accessible from Netbeans
     * UI upon installation, should point to place with additional
     * information about the functionality. If not defined, it
     * defaults to POM's url element.
     */
    public String getHomepageUrl()
    {
        return this.homepageUrl;
    } //-- String getHomepageUrl() 

    /**
     * Method getLibraries
     */
    public java.util.List getLibraries()
    {
        if ( this.libraries == null )
        {
            this.libraries = new java.util.ArrayList();
        }
        
        return this.libraries;
    } //-- java.util.List getLibraries() 

    /**
     * Get Path to the license agreement file.
     */
    public String getLicenseFile()
    {
        return this.licenseFile;
    } //-- String getLicenseFile() 

    /**
     * Get Name of the license. If the user already agreed to the
     * same license before, he/she won't be asked again to agree.
     */
    public String getLicenseName()
    {
        return this.licenseName;
    } //-- String getLicenseName() 

    /**
     * Get Location of the manifest file with Netbeans specific
     * manifest entries.
     */
    public String getManifest()
    {
        return this.manifest;
    } //-- String getManifest() 

    /**
     * Get 
     *                     <p>Type of the module. Possible values
     * are </p>
     *                     <p><b>autoload</b> - Such a module is
     * automatically enabled when some other module requires it and
     * automatically disabled otherwise.</p>
     *                     <p><b>eager</b> - This module type gets
     * automatically enabled when all it's dependencies are
     * satisfied. Disabled otherwise.</p>
     *                     <p><b>normal</b> - This is the default
     * value. This kind of module is enabled/disabled manually by
     * the user. It installs enabled.</p>
     *                             
     */
    public String getModuleType()
    {
        return this.moduleType;
    } //-- String getModuleType() 

    /**
     * Method getNbmResources
     */
    public java.util.List getNbmResources()
    {
        if ( this.nbmResources == null )
        {
            this.nbmResources = new java.util.ArrayList();
        }
        
        return this.nbmResources;
    } //-- java.util.List getNbmResources() 

    /**
     * Get Determines if the module requires restart of the
     * IDE/platform upon installation.
     */
    public boolean isRequiresRestart()
    {
        return this.requiresRestart;
    } //-- boolean isRequiresRestart() 

    /**
     * Method removeDependency
     * 
     * @param dependency
     */
    public void removeDependency(Dependency dependency)
    {
        getDependencies().remove( dependency );
    } //-- void removeDependency(Dependency) 

    /**
     * Method removeLibrary
     * 
     * @param string
     */
    public void removeLibrary(String string)
    {
        getLibraries().remove( string );
    } //-- void removeLibrary(String) 

    /**
     * Method removeNbmResource
     * 
     * @param nbmResource
     */
    public void removeNbmResource(NbmResource nbmResource)
    {
        getNbmResources().remove( nbmResource );
    } //-- void removeNbmResource(NbmResource) 

    /**
     * Set Author of the module. Is used when generating the NBM
     * file.
     * 
     * @param author
     */
    public void setAuthor(String author)
    {
        this.author = author;
    } //-- void setAuthor(String) 

    /**
     * Set Each modules should belong to a cluster. A cluster is a
     * group of related modules. For individual modules it's not
     * that important. Refer to netbeans.org documentation for more
     * details.
     * 
     * @param cluster
     */
    public void setCluster(String cluster)
    {
        this.cluster = cluster;
    } //-- void setCluster(String) 

    /**
     * Set Codenamebase of the module. Primary identification of
     * the module. Usually the package name. Eg.
     * "org.codehaus.mevenide.project". 
     *                     If not defined here, the default value
     * is constructed from groupId and artifactId.
     * 
     * @param codeNameBase
     */
    public void setCodeNameBase(String codeNameBase)
    {
        this.codeNameBase = codeNameBase;
    } //-- void setCodeNameBase(String) 

    /**
     * Set List of module dependencies. The plugin will use it to
     * Generate the OpenIDE-Module-Module-Dependencies manifest
     * entry.
     * 
     * @param dependencies
     */
    public void setDependencies(java.util.List dependencies)
    {
        this.dependencies = dependencies;
    } //-- void setDependencies(java.util.List) 

    /**
     * Set Http URL of the location where the module can be
     * downloaded from the internet. This value put into the NBM
     * and used when generating the Autoupdate Site. Should point
     * directly to the NBM download.
     * 
     * @param distributionUrl
     */
    public void setDistributionUrl(String distributionUrl)
    {
        this.distributionUrl = distributionUrl;
    } //-- void setDistributionUrl(String) 

    /**
     * Set Homepage URL of the module. Is accessible from Netbeans
     * UI upon installation, should point to place with additional
     * information about the functionality. If not defined, it
     * defaults to POM's url element.
     * 
     * @param homepageUrl
     */
    public void setHomepageUrl(String homepageUrl)
    {
        this.homepageUrl = homepageUrl;
    } //-- void setHomepageUrl(String) 

    /**
     * Set groupId:artifactId of artifacts that shall become part
     * of the module and be added on the classpath 
     *                     (ClassPath: manifest entry gets created
     * and the jar is included in the nbm file)
     * 
     * @param libraries
     */
    public void setLibraries(java.util.List libraries)
    {
        this.libraries = libraries;
    } //-- void setLibraries(java.util.List) 

    /**
     * Set Path to the license agreement file.
     * 
     * @param licenseFile
     */
    public void setLicenseFile(String licenseFile)
    {
        this.licenseFile = licenseFile;
    } //-- void setLicenseFile(String) 

    /**
     * Set Name of the license. If the user already agreed to the
     * same license before, he/she won't be asked again to agree.
     * 
     * @param licenseName
     */
    public void setLicenseName(String licenseName)
    {
        this.licenseName = licenseName;
    } //-- void setLicenseName(String) 

    /**
     * Set Location of the manifest file with Netbeans specific
     * manifest entries.
     * 
     * @param manifest
     */
    public void setManifest(String manifest)
    {
        this.manifest = manifest;
    } //-- void setManifest(String) 

    /**
     * Set 
     *                     <p>Type of the module. Possible values
     * are </p>
     *                     <p><b>autoload</b> - Such a module is
     * automatically enabled when some other module requires it and
     * automatically disabled otherwise.</p>
     *                     <p><b>eager</b> - This module type gets
     * automatically enabled when all it's dependencies are
     * satisfied. Disabled otherwise.</p>
     *                     <p><b>normal</b> - This is the default
     * value. This kind of module is enabled/disabled manually by
     * the user. It installs enabled.</p>
     *                             
     * 
     * @param moduleType
     */
    public void setModuleType(String moduleType)
    {
        this.moduleType = moduleType;
    } //-- void setModuleType(String) 

    /**
     * Set List of resources that shall be also included into the
     * Nbm file along with the module jar and library jars.
     * 
     * @param nbmResources
     */
    public void setNbmResources(java.util.List nbmResources)
    {
        this.nbmResources = nbmResources;
    } //-- void setNbmResources(java.util.List) 

    /**
     * Set Determines if the module requires restart of the
     * IDE/platform upon installation.
     * 
     * @param requiresRestart
     */
    public void setRequiresRestart(boolean requiresRestart)
    {
        this.requiresRestart = requiresRestart;
    } //-- void setRequiresRestart(boolean) 


    private String modelEncoding = "UTF-8";

    public void setModelEncoding( String modelEncoding )
    {
        this.modelEncoding = modelEncoding;
    }

    public String getModelEncoding()
    {
        return modelEncoding;
    }}
